@@ -33,8 +33,9 @@ from . import mayan
 from . import persian
 from . import positivist
 from . import ordinal
+from . import utils
 
-__version__ = '2.2.1'
+__version__ = '2.2.2'
 
 __all__ = [
     'holidays', 'armenian', 'bahai', 'coptic', 'dublin',
@@ -43,5 +44,5 @@ __all__ = [
     'indian_civil', 'islamic', 'iso',
     'julian', 'julianday',
     'mayan', 'persian', 'positivist', 'mayan',
-    'ordinal',
+    'ordinal', 'utils'
 ]
